"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.findCookieByName = exports.buildURL = exports.getFullURL = exports.isSearchParams = exports.isFile = exports.isBlob = exports.isFormData = exports.isKindOf = exports.isBrowser = void 0;
const qs_1 = __importDefault(require("qs"));
// istanbul ignore next
function isBrowser() {
    return (typeof window !== "undefined" && typeof window.document !== "undefined");
}
exports.isBrowser = isBrowser;
/**
 * more resilient alternative to instanceof when the object is not native and compiled to es5
 * @param kind - string representation of the object kind
 * @returns - a function that checks if the object is of the given kind
 */
// istanbul ignore next
const isKindOf = (kind) => (data) => {
    const pattern = `[object ${kind}]`;
    return (data &&
        (toString.call(data) === pattern ||
            (typeof data.toString === "function" && data.toString() === pattern)));
};
exports.isKindOf = isKindOf;
// istanbul ignore next
exports.isFormData = (0, exports.isKindOf)("FormData");
// istanbul ignore next
exports.isBlob = (0, exports.isKindOf)("Blob");
// istanbul ignore next
exports.isFile = (0, exports.isKindOf)("File");
// istanbul ignore next
exports.isSearchParams = (0, exports.isKindOf)("URLSearchParams");
function getFullURL(config) {
    var _a, _b;
    // istanbul ignore next
    if (((_a = config.url) === null || _a === void 0 ? void 0 : _a.startsWith("http")) || !config.baseURL) {
        return config.url;
    }
    const baseURL = config.baseURL.replace(/\/$/, "");
    const path = (_b = config.url) === null || _b === void 0 ? void 0 : _b.replace(/^\//, "");
    // istanbul ignore next
    if (!path) {
        return baseURL;
    }
    return `${baseURL}/${path}`;
}
exports.getFullURL = getFullURL;
function buildURL(config) {
    let fullURL = getFullURL(config) || "/";
    const serializedParams = qs_1.default.stringify(config.params, {
        arrayFormat: "brackets",
        encodeValuesOnly: true,
    });
    if (serializedParams) {
        fullURL += fullURL.indexOf("?") === -1 ? "?" : "&";
    }
    return `${fullURL}${serializedParams}`;
}
exports.buildURL = buildURL;
// istanbul ignore next
function findCookieByName(name) {
    if (typeof document !== "undefined") {
        const match = document.cookie.match(new RegExp("(^|;\\s*)(" + name + ")=([^;]*)"));
        return match ? decodeURIComponent(match[3]) : undefined;
    }
    return undefined;
}
exports.findCookieByName = findCookieByName;
